@@ -36,40 +36,40 @@ the following application events are fired exactly one time at startup in the fo
 * `on_app_init`: fired **after** :class:`ConsoleApp` app instance got initialized (detected config files)
   and **before** the image and sound resources and app states get loaded and the GUI framework app class instance gets
   initialized.
-* `on_app_start`: fired **after** the call of the method :meth:`~MainAppBase.run_app` and **before** the command line
-  options get parsed.
-* `on_app_run`: fired **after** the parsing of the command line arguments and options and **before** all portion
-  resources got imported.
-* `on_app_build`: fired **after** all portion resources got loaded/imported and **before** the framework event
+* `on_app_run`: fired **from within** the method :meth:`~MainAppBase.run_app`, **after** the parsing of the command line
+  arguments and options, and **before** all portion resources got imported.
+* `on_app_build`: fired **after** all portion resources got loaded/imported, and **before** the framework event
   loop of the used GUI framework gets started.
+* `on_app_started`: fired **after** all app initializations, and the start of and the initial processing of the
+  framework event loop.
 
 .. note::
-    the `on_app_build` application event has to be fired by the used GUI framework.
+    the application events `on_app_build` and `on_app_started` have to be fired by the used GUI framework.
 
 .. hint::
-    depending on the used gui framework there can be more app start events. e.g. the :mod:`ae.kivy.apps` module fires
-    the events :meth:`~ae.kivy.apps.KivyMainApp.on_app_built` and :meth:`~ae.kivy.apps.KivyMainApp.on_app_started` (all
-    of them fired after :meth:`~ae.kivy.apps.KivyMainApp.on_app_run` and
-    :meth:`~ae.kivy.apps.KivyMainApp.on_app_build`). see also :ref:`kivy application events`.
+    depending on the used gui framework there can be more app start events. e.g. the :mod:`ae.kivy.apps` module
+    fires the events :meth:`~ae.kivy.apps.KivyMainApp.on_app_built` and :meth:`~ae.kivy.apps.KivyMainApp.on_app_start`
+    (all of them fired after
+    :meth:`~ae.kivy.apps.KivyMainApp.on_app_run` and :meth:`~ae.kivy.apps.KivyMainApp.on_app_build`).
+    see also :ref:`kivy application events`.
 
 
 when an application gets stopped then the following events get fired in the following order:
 
-* `on_app_stop`: fired **after** the call of the method :meth:`~MainAppBase.stop_app` and **before** the framework win
-  will be closed.
 * `on_app_exit`: fired **after* framework win got closed and just **before** the event loop of the GUI framework will be
   stopped and the app shutdown.
 * `on_app_quit`: fired **after** the event loop of the GUI framework got stopped and before the :meth:`AppBase.shutdown`
   method will be called.
 
 .. note::
-    the `on_app_stop` and `on_app_exit` events will only be fired if the app is explicitly calling the
+    the `on_app_exit` events will only be fired if the app is explicitly calling the
     :meth:`~MainAppBase.stop_app` method.
 
 .. hint::
-    depending on the used gui framework there can be more events. e.g. the :mod:`~ae.kivy.apps` module fires the event
-    :meth:`~ae.kivy.apps.KivyMainApp.on_app_stopped` (before :meth:`~ae.kivy.apps.KivyMainApp.on_app_stop`
-    respectively :meth:`~ae.kivy.apps.KivyMainApp.on_app_quit`).
+    depending on the used gui framework there can be more events. e.g. the :mod:`~ae.kivy.apps` module fires the events
+    :meth:`~ae.kivy.apps.KivyMainApp.on_app_stop` and clock tick later :meth:`~ae.kivy.apps.KivyMainApp.on_app_stopped`
+    (both of them before :meth:`~ae.kivy.apps.KivyMainApp.on_app_quit` get fired).
+    see also :ref:`kivy application events`.
 
 
 application status
@@ -419,7 +419,8 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 from ae.base import (                                                                                   # type: ignore
     CFG_EXT, INI_EXT, NAME_PARTS_SEP, UNSET,
-    instantiate_config_parser, norm_name, norm_path, now_str, os_platform, snake_to_camel, stack_var)
+    instantiate_config_parser, norm_name, norm_path, now_str, os_platform, request_app_permissions, snake_to_camel,
+    stack_var)
 from ae.files import RegisteredFile                                                                     # type: ignore
 from ae.paths import (                                                                                  # type: ignore
     add_common_storage_paths, copy_file, copy_tree, normalize, path_folders, path_name, placeholder_path,
@@ -432,7 +433,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.3.91'
+__version__ = '0.3.92'
 
 
 APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name to store app state
@@ -1198,11 +1199,7 @@ class MainAppBase(ConsoleApp, ABC):
 
     def on_app_run(self):
         """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_run default/fallback event handler called")
-
-    def on_app_start(self):
-        """ default/fallback flow change confirmation event handler, used to load app resources. """
-        self.vpo("MainAppBase.on_app_start default/fallback event handler called - loading app resources")
+        self.vpo("MainAppBase.on_app_run default/fallback event handler called - loading resources (img, audio, i18n)")
 
         self.load_images()
 
@@ -1212,9 +1209,10 @@ class MainAppBase(ConsoleApp, ABC):
         register_translations_path("{ado}")
         self.load_translations(self.lang_code)
 
-    def on_app_stop(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_stop default/fallback event handler called")
+    def on_app_started(self):
+        """ app initialization event - the last one on app startup. """
+        self.vpo("MainAppBase.on_app_started default/fallback event handler called - requesting app permissions")
+        request_app_permissions()
 
     def on_debug_level_change(self, level_name: str, _event_kwargs: EventKwargsType) -> bool:
         """ debug level app state change flow change confirmation event handler.
@@ -1412,11 +1410,8 @@ class MainAppBase(ConsoleApp, ABC):
 
     def run_app(self):
         """ startup main and framework applications. """
-        self.dpo(f"MainAppBase.run_app {self.app_name}")
-
-        self.call_method('on_app_start')
-
         super().run_app()                               # parse command line arguments into config options
+        self.dpo(f"MainAppBase.run_app {self.app_name}")
 
         self.call_method('on_app_run')
 
@@ -1515,10 +1510,8 @@ class MainAppBase(ConsoleApp, ABC):
         self.dpo(f"MainAppBase.stop_app {exit_code}")
         self._exit_code = exit_code
 
-        self.call_method('on_app_stop')
-
         if self.framework_win:
-            self.framework_win.close()      # close window to save app state data
+            self.framework_win.close()      # close window to save app state data and fire on_app_stop
 
         self.call_method('on_app_exit')
 
