@@ -87,11 +87,10 @@ class ImplementationOfMainApp(MainAppBase):
     app_state_version_upgrade_call_counter = 0
     app_state_version_upgrade_last_version = -1
     build_called = False
+    started_called = False
     load_state_called = False
     init_called = False
     run_called = False
-    start_called = False
-    stop_called = False
     setup_state_called = False
     flow_id_called = False
     flow_path_called = False
@@ -111,7 +110,7 @@ class ImplementationOfMainApp(MainAppBase):
         self.framework_win = MainWindow()
         self.framework_root = RootLayout()
         self.init_called = True
-        self.call_method('on_app_start')
+        self.call_method('on_app_run')
         self.call_method('on_app_build')
         self.tst_var = ""
 
@@ -127,25 +126,21 @@ class ImplementationOfMainApp(MainAppBase):
         self.setup_state_called = True
         super().setup_app_states(app_states)
 
-    def run_app(self):
-        """ run app """
-        self.run_called = True
-        super().run_app()
-
-    def stop_app(self, exit_code=0):
-        """ stop app event loop. """
-        self.stop_called = True
-        super().stop_app(exit_code=exit_code)
-
-    def on_app_start(self):
+    def on_app_run(self):
         """ init app """
-        super().on_app_start()
-        self.start_called = True
+        super().on_app_run()
+        self.run_called = True
 
     def on_app_build(self):
         """ build app """
         super().on_app_build()
         self.build_called = True
+        self.on_app_started()
+
+    def on_app_started(self):
+        """ app fully started event handler """
+        super().on_app_started()
+        self.started_called = True
 
     def on_app_state_tst_var_save(self, font_size: float) -> float:
         """ test save event for TST_VAR app state. """
@@ -431,14 +426,8 @@ class TestCallbacks:
 
     def test_run(self, restore_app_env):
         app = ImplementationOfMainApp()
-        assert not app.run_called
-        app.run_app()
         assert app.run_called
 
-    def test_start(self, restore_app_env):
-        app = ImplementationOfMainApp()
-        assert app.start_called
-
     def test_flow_id(self, restore_app_env):
         app = ImplementationOfMainApp()
         assert not app.flow_id_called
@@ -1038,12 +1027,6 @@ class TestOtherMainAppMethods:
         app.call_method('on_flow_id')
         assert app.flow_id_called
 
-    def test_call_method_return(self, ini_file, restore_app_env):
-        app = ImplementationOfMainApp(additional_cfg_files=(ini_file,))
-        assert not app.run_called
-        app.run_app()
-        assert app.run_called
-
     def test_call_method_invalid_method(self, ini_file, restore_app_env):
         app = ImplementationOfMainApp(additional_cfg_files=(ini_file,))
         assert app.call_method('invalid_method_name') is None
